@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 int
@@ -30,7 +31,7 @@ osip_message_set_error_info (osip_message_t * sip, const char *hvalue)
   osip_error_info_t *error_info;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_error_info_init (&error_info);
@@ -42,15 +43,14 @@ osip_message_set_error_info (osip_message_t * sip, const char *hvalue)
       osip_error_info_free (error_info);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->error_infos, error_info, -1);
   return 0;
 }
 
 int
-osip_message_get_error_info (const osip_message_t * sip, int pos, osip_error_info_t ** dest)
+osip_message_get_error_info (const osip_message_t * sip, int pos,
+			     osip_error_info_t ** dest)
 {
   osip_error_info_t *error_info;
 
