@@ -31,6 +31,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 /* adds the from header to message.              */
@@ -42,7 +43,7 @@ osip_message_set_from (osip_message_t * sip, const char *hvalue)
 {
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   if (sip->from != NULL)
@@ -50,9 +51,7 @@ osip_message_set_from (osip_message_t * sip, const char *hvalue)
   i = osip_from_init (&(sip->from));
   if (i != 0)
     return -1;
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   i = osip_from_parse (sip->from, hvalue);
   if (i != 0)
     {
@@ -269,7 +268,7 @@ osip_from_to_str (const osip_from_t * from, char **dest)
   char *url;
   char *buf;
   int i;
-  int len;
+  size_t len;
 
   *dest = NULL;
   if ((from == NULL) || (from->url == NULL))
@@ -303,12 +302,13 @@ osip_from_to_str (const osip_from_t * from, char **dest)
   {
     int pos = 0;
     osip_generic_param_t *u_param;
-    int plen;
+    size_t plen;
     char *tmp;
 
     while (!osip_list_eol (from->gen_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (from->gen_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (from->gen_params, pos);
 
 	if (u_param->gvalue == NULL)
 	  plen = strlen (u_param->gname) + 2;
@@ -358,7 +358,8 @@ osip_from_set_url (osip_from_t * from, osip_uri_t * url)
 }
 
 int
-osip_from_param_get (osip_from_t * from, int pos, osip_generic_param_t ** fparam)
+osip_from_param_get (osip_from_t * from, int pos,
+		     osip_generic_param_t ** fparam)
 {
   *fparam = NULL;
   if (from == NULL)
@@ -402,7 +403,8 @@ osip_from_clone (const osip_from_t * from, osip_from_t ** dest)
 
     while (!osip_list_eol (from->gen_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (from->gen_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (from->gen_params, pos);
 	i = osip_generic_param_clone (u_param, &dest_param);
 	if (i != 0)
 	  {
@@ -455,7 +457,8 @@ osip_from_compare (osip_from_t * from1, osip_from_t * from2)
 
     while (!osip_list_eol (from1->gen_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (from1->gen_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (from1->gen_params, pos);
 	if (0 == strncmp (u_param->gname, "tag", 3))
 	  {
 	    tag1 = u_param->gvalue;
@@ -470,7 +473,8 @@ osip_from_compare (osip_from_t * from1, osip_from_t * from2)
 
     while (!osip_list_eol (from2->gen_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (from2->gen_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (from2->gen_params, pos);
 	if (0 == strncmp (u_param->gname, "tag", 3))
 	  {
 	    tag2 = u_param->gvalue;
