@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 
 
 /* adds the mime_version header to message.       */
@@ -33,7 +34,7 @@ osip_message_set_mime_version (osip_message_t * sip, const char *hvalue)
 {
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   if (sip->mime_version != NULL)
@@ -41,9 +42,7 @@ osip_message_set_mime_version (osip_message_t * sip, const char *hvalue)
   i = osip_mime_version_init (&(sip->mime_version));
   if (i != 0)
     return -1;
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   i = osip_mime_version_parse (sip->mime_version, hvalue);
   if (i != 0)
     {
