@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 
 int
 osip_to_init (osip_to_t ** to)
@@ -38,7 +39,7 @@ osip_message_set_to (osip_message_t * sip, const char *hvalue)
 {
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   if (sip->to != NULL)
@@ -46,9 +47,7 @@ osip_message_set_to (osip_message_t * sip, const char *hvalue)
   i = osip_to_init (&(sip->to));
   if (i != 0)
     return -1;
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   i = osip_to_parse (sip->to, hvalue);
   if (i != 0)
     {
