@@ -81,7 +81,8 @@ osip_uri_init (osip_uri_t ** url)
 /* return it only if it is located before the */
 /* second separator. */
 char *
-next_separator (const char *ch, int separator_osip_to_find, int before_separator)
+next_separator (const char *ch, int separator_osip_to_find,
+		int before_separator)
 {
   char *ind;
   char *tmp;
@@ -122,7 +123,7 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
   const char *tmp;
 
   /* basic tests */
-  if (buf == NULL || buf[0]=='\0')
+  if (buf == NULL || buf[0] == '\0')
     return -1;
 
   tmp = strchr (buf, ':');
@@ -140,7 +141,7 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
       (0 != osip_strncasecmp (url->scheme, "sip", 3)
        && 0 != osip_strncasecmp (url->scheme, "sips", 4)))
     {				/* Is not a sipurl ! */
-      int i = strlen (tmp + 1);
+      size_t i = strlen (tmp + 1);
 
       if (i < 2)
 	return -1;
@@ -390,13 +391,15 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
 	      osip_free (hname);
 	      return -1;
 	    }
-	  hvalue = (char *) osip_malloc (headers + strlen (headers) - equal + 1);
+	  hvalue =
+	    (char *) osip_malloc (headers + strlen (headers) - equal + 1);
 	  if (hvalue == NULL)
 	    {
 	      osip_free (hname);
 	      return -1;
 	    }
-	  osip_strncpy (hvalue, equal + 1, headers + strlen (headers) - equal);
+	  osip_strncpy (hvalue, equal + 1,
+			headers + strlen (headers) - equal);
 	  __osip_uri_unescape (hvalue);
 	}
 
@@ -511,8 +514,8 @@ int
 osip_uri_to_str (const osip_uri_t * url, char **dest)
 {
   char *buf;
-  int len;
-  int plen;
+  size_t len;
+  size_t plen;
   char *tmp;
   const char *scheme;
 
@@ -524,14 +527,13 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
   if (url->scheme == NULL && url->string != NULL)
     return -1;
   if (url->string == NULL && url->scheme == NULL)
-    scheme = "sip"; /* default is sipurl */
+    scheme = "sip";		/* default is sipurl */
   else
     scheme = url->scheme;
 
   if (url->string != NULL)
     {
-      buf =
-	(char *) osip_malloc (strlen (scheme) + strlen (url->string) + 3);
+      buf = (char *) osip_malloc (strlen (scheme) + strlen (url->string) + 3);
       if (buf == NULL)
 	return -1;
       *dest = buf;
@@ -544,9 +546,9 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 
   len = strlen (scheme) + 1 + strlen (url->host) + 5;
   if (url->username != NULL)
-    len = len + strlen (url->username) + 10;	/* count escaped char */
+    len = len + (strlen (url->username) * 3) + 1;    /* count escaped char */
   if (url->password != NULL)
-    len = len + strlen (url->password) + 10;
+    len = len + (strlen (url->password) * 3) + 1;
   if (url->port != NULL)
     len = len + strlen (url->port) + 3;
 
@@ -639,7 +641,8 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 	char *tmp1;
 	char *tmp2;
 
-	u_header = (osip_uri_header_t *) osip_list_get (url->url_headers, pos);
+	u_header =
+	  (osip_uri_header_t *) osip_list_get (url->url_headers, pos);
 	tmp1 = __osip_uri_escape_header_param (u_header->gname);
 	tmp2 = __osip_uri_escape_header_param (u_header->gvalue);
 
@@ -691,7 +694,8 @@ osip_uri_free (osip_uri_t * url)
 
     while (!osip_list_eol (url->url_headers, pos))
       {
-	u_header = (osip_uri_header_t *) osip_list_get (url->url_headers, pos);
+	u_header =
+	  (osip_uri_header_t *) osip_list_get (url->url_headers, pos);
 	osip_list_remove (url->url_headers, pos);
 	osip_uri_header_free (u_header);
       }
@@ -829,7 +833,8 @@ osip_uri_param_freelist (osip_list_t * params)
 }
 
 int
-osip_uri_param_get_byname (osip_list_t * params, char *pname, osip_uri_param_t ** url_param)
+osip_uri_param_get_byname (osip_list_t * params, char *pname,
+			   osip_uri_param_t ** url_param)
 {
   int pos = 0;
   osip_uri_param_t *u_param;
@@ -849,7 +854,8 @@ osip_uri_param_get_byname (osip_list_t * params, char *pname, osip_uri_param_t *
 }
 
 int
-osip_uri_param_clone (const osip_uri_param_t * uparam, osip_uri_param_t ** dest)
+osip_uri_param_clone (const osip_uri_param_t * uparam,
+		      osip_uri_param_t ** dest)
 {
   int i;
   osip_uri_param_t *up;
@@ -890,11 +896,11 @@ osip_uri_param_clone (const osip_uri_param_t * uparam, osip_uri_param_t ** dest)
 char *
 __osip_uri_escape_nonascii_and_nondef (const char *string, const char *def)
 {
-  int alloc = strlen (string) + 1;
-  int length;
+  size_t alloc = strlen (string) + 1;
+  size_t length;
   char *ns = osip_malloc (alloc);
   unsigned char in;
-  int newlen = alloc;
+  size_t newlen = alloc;
   int index = 0;
   const char *tmp;
   int i;
@@ -974,7 +980,7 @@ __osip_uri_escape_header_param (char *string)
 void
 __osip_uri_unescape (char *string)
 {
-  int alloc = strlen (string) + 1;
+  size_t alloc = strlen (string) + 1;
   unsigned char in;
   int index = 0;
   unsigned int hex;
