@@ -22,6 +22,7 @@
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
+#include <osipparser2/osip_parser.h>
 #include "parser.h"
 
 /* adds the via header to message.              */
@@ -34,7 +35,7 @@ osip_message_set_via (osip_message_t * sip, const char *hvalue)
   osip_via_t *via;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_via_init (&via);
@@ -46,9 +47,7 @@ osip_message_set_via (osip_message_t * sip, const char *hvalue)
       osip_via_free (via);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->vias, via, -1);
   return 0;
 }
@@ -58,7 +57,7 @@ osip_message_set_via (osip_message_t * sip, const char *hvalue)
 /* OUTPUT: osip_message_t *sip | structure to save results.  */
 /* returns -1 on error. */
 int
-msg_appendtopvia (osip_message_t * sip, const char *hvalue)
+osip_message_append_via (osip_message_t * sip, const char *hvalue)
 {
   osip_via_t *via;
   int i;
@@ -72,9 +71,7 @@ msg_appendtopvia (osip_message_t * sip, const char *hvalue)
       osip_via_free (via);
       return -1;
     }
-#ifdef USE_TMP_BUFFER
   sip->message_property = 2;
-#endif
   osip_list_add (sip->vias, via, 0);
   return 0;
 }
@@ -294,8 +291,8 @@ int
 osip_via_to_str (const osip_via_t * via, char **dest)
 {
   char *buf;
-  int len;
-  int plen;
+  size_t len;
+  size_t plen;
   char *tmp;
 
   *dest = NULL;
@@ -338,7 +335,8 @@ osip_via_to_str (const osip_via_t * via, char **dest)
 
     while (!osip_list_eol (via->via_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (via->via_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (via->via_params, pos);
 
 	if (u_param->gvalue == NULL)
 	  plen = strlen (u_param->gname) + 2;
@@ -472,7 +470,8 @@ osip_via_clone (const osip_via_t * via, osip_via_t ** dest)
 
     while (!osip_list_eol (via->via_params, pos))
       {
-	u_param = (osip_generic_param_t *) osip_list_get (via->via_params, pos);
+	u_param =
+	  (osip_generic_param_t *) osip_list_get (via->via_params, pos);
 	i = osip_generic_param_clone (u_param, &dest_param);
 	if (i != 0)
 	  {
